https

package
v0.0.0-...-cdbcc9a Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 19, 2017 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Manager

type Manager interface {
	GetCertificate(clientHello *tls.ClientHelloInfo) (*tls.Certificate, error)
}

The https manager which provides the certificate.

func NewLetsencryptManager

func NewLetsencryptManager(email string, hosts []string, cacheFile string) (m Manager, err error)

Register the email to letsencrypt, cache the certs in cacheFile, set allow hosts. @remark set hosts to empty string when allow all request hosts, but maybe attack. @remark set email to nil to not regiester, use empty email to request cert from letsencrypt. @remark set cacheFile to empty string to not cache the info and certs. @remark we only use tls validate, https://github.com/ietf-wg-acme/acme/blob/master/draft-ietf-acme-acme.md#tls-with-server-name-indication-tls-sni

func NewSelfSignManager

func NewSelfSignManager(certFile, keyFile string) (m Manager, err error)

Directories

Path Synopsis
fork from https://github.com/rsc/letsencrypt/tree/master/vendor/github.com/xenolf/lego/acme fork from https://github.com/xenolf/lego/tree/master/acme
fork from https://github.com/rsc/letsencrypt/tree/master/vendor/github.com/xenolf/lego/acme fork from https://github.com/xenolf/lego/tree/master/acme
from gopkg.in/square/go-jose.v1
from gopkg.in/square/go-jose.v1
cipher
from gopkg.in/square/go-jose.v1/cipher
from gopkg.in/square/go-jose.v1/cipher
json
from gopkg.in/square/go-jose.v1/json
from gopkg.in/square/go-jose.v1/json
Package letsencrypt obtains TLS certificates from LetsEncrypt.org.
Package letsencrypt obtains TLS certificates from LetsEncrypt.org.
net
context
Package context defines the Context type, which carries deadlines, cancelation signals, and other request-scoped values across API boundaries and between processes.
Package context defines the Context type, which carries deadlines, cancelation signals, and other request-scoped values across API boundaries and between processes.
time
rate
Package rate provides a rate limiter.
Package rate provides a rate limiter.

Jump to